==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/General/rgscan/translations/rgscan_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU" sourcelanguage="en_GB">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>Сканер ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="29"/>
        <source>Write track gain/peak</source>
        <translation>Записывать пик/усиление для трека</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="56"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="61"/>
        <source>Progress</source>
        <translation>Завершено</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="66"/>
        <source>Track Gain</source>
        <translation>Усиление трека</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="71"/>
        <source>Album Gain</source>
        <translation>Усиление альбома</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="76"/>
        <source>Track Peak</source>
        <translation>Пик трека</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="81"/>
        <source>Album Peak</source>
        <translation>Пик альбома</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="89"/>
        <source>Calculate</source>
        <translation>Рассчитать</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="96"/>
        <source>Write Tags</source>
        <translation>Записать теги</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="103"/>
        <source>Write album gain/peak</source>
        <translation>Записывать пик/усиление для альбома</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="114"/>
        <location filename="../rgscandialog.cpp" line="212"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="136"/>
        <location filename="../rgscandialog.cpp" line="207"/>
        <source>%1 dB</source>
        <translation>%1 дБ</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="28"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>Модуль сканир. ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="49"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>О модуле сканирования ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>Модуль сканирования ReplayGain для Qmmp</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>Данный модуль сканирует аудио-файлы и выдаёт информацию для нормализации громкости</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Based on source code by:</source>
        <translation>Основан на исходном коде следующих разработчиков:</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Frank Klemm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>Сканер ReplaGain</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/General/rgscan/translations/rgscan_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU" sourcelanguage="en_GB">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>Сканер ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="84"/>
        <source>Write track gain/peak</source>
        <translation>Записывать пик/усиление для трека</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="42"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="47"/>
        <source>Progress</source>
        <translation>Завершено</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="52"/>
        <source>Track Gain</source>
        <translation>Усиление трека</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="57"/>
        <source>Album Gain</source>
        <translation>Усиление альбома</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="62"/>
        <source>Track Peak</source>
        <translation>Пик трека</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="67"/>
        <source>Album Peak</source>
        <translation>Пик альбома</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="77"/>
        <source>Skip already scanned files</source>
        <translation>Пропустить отсканированные файлы</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="113"/>
        <source>Calculate</source>
        <translation>Рассчитать</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="120"/>
        <source>Write Tags</source>
        <translation>Записать теги</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="91"/>
        <source>Write album gain/peak</source>
        <translation>Записывать пик/усиление для альбома</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="130"/>
        <location filename="../rgscandialog.cpp" line="241"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="140"/>
        <location filename="../rgscandialog.cpp" line="141"/>
        <location filename="../rgscandialog.cpp" line="165"/>
        <location filename="../rgscandialog.cpp" line="236"/>
        <source>%1 dB</source>
        <translation>%1 дБ</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="30"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>Модуль сканир. ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>О модуле сканирования ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>Модуль сканирования ReplayGain для Qmmp</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>Данный модуль сканирует аудио-файлы и выдаёт информацию для нормализации громкости</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>Based on source code by:</source>
        <translation>Основан на исходном коде следующих разработчиков:</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="57"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="58"/>
        <source>Frank Klemm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>Сканер ReplaGain</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
